@@ -32,13 +32,13 @@
 // Okteta core
 #include <charcodec.h>
 #include <abstractbytearraymodel.h>
-// KDE
-#include <KLocale>
+// KF5
+#include <KLocalizedString>
 // Qt
-#include <QtGui/QApplication>
+#include <QApplication>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 ReplaceTool::ReplaceTool()
@@ -47,7 +47,7 @@ ReplaceTool::ReplaceTool()
     mByteArrayView( 0 ),
     mByteArrayModel( 0 )
 {
-    setObjectName( QLatin1String( "Replace" ) );
+    setObjectName( QStringLiteral( "Replace" ) );
 }
 
 bool ReplaceTool::isApplyable() const
@@ -80,7 +80,7 @@ void ReplaceTool::setTargetModel( AbstractModel* model )
 
     if( mByteArrayView && mByteArrayModel )
     {
-        connect( mByteArrayView, SIGNAL(readOnlyChanged(bool)), SLOT(onReadOnlyChanged(bool)) );
+        connect( mByteArrayView, &ByteArrayView::readOnlyChanged, this, &ReplaceTool::onReadOnlyChanged );
         // TODO: update isApplyable on cursor movement and size changes
     }
 
@@ -142,6 +142,13 @@ void ReplaceTool::replace( KFindDirection direction, bool fromCursor, bool inSel
     if( inSelection )
     {
         const Okteta::AddressRange selection = mByteArrayView->selection();
+        if( ! selection.isValid() )
+        {
+            // nothing selected, so skip any search and finish now
+            emit finished( false, 0 );
+            return;
+        }
+
         mReplaceFirstIndex = selection.start();
         mReplaceLastIndex =  selection.end();
         startIndex = selection.start();
