@@ -20,14 +20,13 @@
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-
-
 #include "utf8stringdata.h"
 
+#include "../../structlogging.h"
+
 #include <QVarLengthArray>
 
-#include <KLocale>
-#include <KDebug> //TODO remove
+#include <KLocalizedString>
 
 #include <abstractbytearraymodel.h>
 
@@ -35,6 +34,7 @@
 #include "../dummydatainformation.h"
 #include "stringdatainformation.h"
 
+
 Utf8StringData::Utf8StringData(StringDataInformation* parent)
     : StringData(parent), mOneByteCount(0), mTwoByteCount(0), mThreeByteCount(0), mFourByteCount(0), mNonBMPCount(0)
 {
@@ -66,7 +66,7 @@ QString Utf8StringData::stringValue(int row) const
     uint val = mCodePoints.at(row);
     QString number = QString::number(val, 16).toUpper();
     if (number.length() == 1)
-        number = QLatin1String("0") + number;
+        number = QStringLiteral("0") + number;
     if (val > UNICODE_MAX)
         return i18n("Value too big: 0x%1", number);
     else if (val > BMP_MAX) {
@@ -317,7 +317,7 @@ qint64 Utf8StringData::read(Okteta::AbstractByteArrayModel* input, Okteta::Addre
                 terminate = true;
         }
         if (mMode == None) {
-            kDebug() << "no termination mode set!!";
+            qCDebug(LOG_KASTEN_OKTETA_CONTROLLERS_STRUCTURES) << "no termination mode set!!";
             Q_ASSERT(false);
         }
         if (terminate)
